@@ -20,4 +20,11 @@ else:
     FINTIX_IO_LOG_DIR = "/var/log/fintix"
 
 LOCAL_DEPLOY_MODEL_REPO = os.path.join(FINTIX_IO_DATA_DIR, "models", "deploy")
-LOCAL_TRAINING_MODEL_REPO = os.path.join(FINTIX_IO_DATA_DIR, "models", "training")
+LOCAL_TRAINING_MODEL_REPO = os.path.join(FINTIX_IO_DATA_DIR, "models", "train")
+
+MILLISECOND_PER_UNIT = {
+    "s": 1000,
+    "m": 60 * 1000,
+    "h": 60 * 60 * 1000,
+    "d": 24 * 60 * 60 * 1000
+}
